// Prosze dopisac kod, dodac nowe pliki, tak aby program wykonywal się
// a wynik jego dzialania byl taki sam jak podany na końcu tego pliku
//
// Pliku Main.cpp, nie wolno modyfikowac.
// 
// Celem tego ćwiczenia jest zrozumienie, jak zorganizować kod w programie składającym się z wielu plików, 
// oraz jak za pomocą funkcji operować na strukturach danych w języku C++. 
// W ramach zadania zaimplementujecie listę jednokierunkową, która pozwoli na dodawanie elementów, 
// wyświetlanie zawartości listy oraz wyszukiwanie wartości. 
// Przy okazji utrwalicie proces kompilacji oraz linkowania programów wieloplikowych.
//
// Programem valgrind można sprawdzić poprawne zarządzanie pamięcią.
//
// Przy wykonaniu zadania nie wolno korzystac z internetu, notatek,
// ani żadnych innych materialow (w tym własnych wczesniej
// przygotowanych plikow oprócz makefile/cmake, chyba że polecenie stanowi inaczej)
//
// Zadania oceniane są wg algorytmu:
//     Warunkiem przystąpienia do oceniania programu jest jego poprawna kompilacja (bez błędów).
//     Dokumentacja - 1 pkt.
//     Poprawna kompilacja (bez ostrzeżeń) - 2 pkt.
//     Poprawne wykonanie (odpowiednie wyjście, brak wycieków pamięci itp.) - 3 pkt.
//     Ocena kodu (pod względem projektowym, zgodności z OOP, przejrzystości oraz sposobu implantacji) - maks. 4 pkt.
//
// Programy niezgodne z tematem/celem zadania,
// ale kompilujące się (i dające potencjalnie "poprawne" wyjście) będą oceniane na 0 pkt.
//
//
// Kody źródłowe muszą znajdować się w katalogu do którego nikt oprócz
// właściciela nie ma praw dostępu.
// Rozwiazanie (czyli katalog z plikami i Main.cpp należy wgrać do UPEL 
// jako archiwum tar.gz
// UWAGA:
// * archiwum nie powinno zawierać katalogu build/
// * tworzenie archiwum: tar -czvf nazwa.tar.gz katalog/
// * brak wysłanego rozwiązania (bez względu na jego ukończenie),
//   jest tożsame z brakiem obecności na zajęciach.



#include "List.h"
#include "ListOperations.h"
#include <iostream>

int main() {
    List list;
    initializeList(&list); // Inicjalizacja listy

    insert(&list, 10);
    
    print(&list);

    insert(&list, 20);
    insert(&list, 30);

    print(&list);

    std::cout << "Number of elements: " << countElements(&list) << std::endl;
    std::cout << "Is 20 in the list? " << (findValue(&list, 20) ? "Yes" : "No") << std::endl;

    // Wyświetlanie elementu o indeksie 1
    std::cout << "Element at index 1: " << getElementAt(&list, 1) << std::endl;

    // Czyszczenie listy
    clearList(&list);
    std::cout << "List after clearing: ";
    print(&list);

    return 0;
}


/** Wynik dzialania programu:

10
30 20 10
Number of elements: 3
Is 20 in the list? Yes
Element at index 1: 20
List after clearing:

*/